@@ -4,8 +4,6 @@ import operator
 
 from tests import TestCase
 
-from mutagen._compat import text_type, xrange, PY2, PY3, iteritems, izip, \
-    integer_types
 from mutagen._constants import GENRES
 from mutagen.id3._tags import read_frames, save_frame, ID3Header
 from mutagen.id3._util import ID3SaveConfig, is_valid_frame_id, \
@@ -480,12 +478,8 @@ class TVariousFrames(TestCase):
             tag = kind._fromData(_23, 0, data)
             self.assertTrue(isinstance(tag.__str__(), str))
             self.assertTrue(isinstance(tag.__repr__(), str))
-            if PY2:
-                if hasattr(tag, "__unicode__"):
-                    self.assertTrue(isinstance(tag.__unicode__(), unicode))
-            else:
-                if hasattr(tag, "__bytes__"):
-                    self.assertTrue(isinstance(tag.__bytes__(), bytes))
+            if hasattr(tag, "__bytes__"):
+                self.assertTrue(isinstance(tag.__bytes__(), bytes))
 
     def test_tag_write(self):
         for frame_id, data, value, intval, info in self.DATA:
@@ -529,18 +523,18 @@ class TVariousFrames(TestCase):
             self.assertEquals(value, tag)
             if 'encoding' not in info:
                 self.assertRaises(AttributeError, getattr, tag, 'encoding')
-            for attr, value in iteritems(info):
+            for attr, value in info.items():
                 t = tag
                 if not isinstance(value, list):
                     value = [value]
                     t = [t]
-                for value, t in izip(value, iter(t)):
+                for value, t in zip(value, iter(t)):
                     if isinstance(value, float):
                         self.failUnlessAlmostEqual(value, getattr(t, attr), 5)
                     else:
                         self.assertEquals(value, getattr(t, attr))
 
-                    if isinstance(intval, integer_types):
+                    if isinstance(intval, int):
                         self.assertEquals(intval, operator.pos(t))
                     else:
                         self.assertRaises(TypeError, operator.pos, t)
@@ -1276,11 +1270,11 @@ class TTCON(TestCase):
         self.assertEquals(self._g(""), [])
 
     def test_num(self):
-        for i in xrange(len(GENRES)):
+        for i in range(len(GENRES)):
             self.assertEquals(self._g("%02d" % i), [GENRES[i]])
 
     def test_parened_num(self):
-        for i in xrange(len(GENRES)):
+        for i in range(len(GENRES)):
             self.assertEquals(self._g("(%02d)" % i), [GENRES[i]])
 
     def test_unknown(self):
@@ -1405,10 +1399,9 @@ class TID3TimeStamp(TestCase):
         self.assert_(u > s > t)
 
     def test_types(self):
-        if PY3:
-            self.assertRaises(TypeError, ID3TimeStamp, b"blah")
+        self.assertRaises(TypeError, ID3TimeStamp, b"blah")
         self.assertEquals(
-            text_type(ID3TimeStamp(u"2000-01-01")), u"2000-01-01")
+            str(ID3TimeStamp(u"2000-01-01")), u"2000-01-01")
         self.assertEquals(
             bytes(ID3TimeStamp(u"2000-01-01")), b"2000-01-01")
 
@@ -1441,11 +1434,14 @@ class TFrameTest(object):
 
     @classmethod
     def create_frame_tests(cls):
+        tests = {}
         for kind in (list(Frames.values()) + list(Frames_2_2.values())):
             new_type = type(cls.__name__ + kind.__name__,
                             (cls, TestCase), {"FRAME": kind})
-            assert new_type.__name__ not in globals()
-            globals()[new_type.__name__] = new_type
+            assert new_type.__name__ not in tests
+            tests[new_type.__name__] = new_type
+        for name, test_type in sorted(tests.items()):
+            globals()[name] = test_type
 
 
 TFrameTest.create_frame_tests()
@@ -1470,7 +1466,7 @@ class TTimeStampTextFrame(TestCase):
 
     def test_compare_to_unicode(self):
         frame = TimeStampTextFrame(encoding=0, text=[u'1987', u'1988'])
-        self.failUnlessEqual(frame, text_type(frame))
+        self.failUnlessEqual(frame, str(frame))
 
 
 class TTextFrame(TestCase):
@@ -1681,14 +1677,9 @@ class TAPIC(TestCase):
 
     def test_repr(self):
         frame = APIC(encoding=0, mime=u"m", type=3, desc=u"d", data=b"\x42")
-        if PY2:
-            expected = (
-                "APIC(encoding=<Encoding.LATIN1: 0>, mime=u'm', "
-                "type=<PictureType.COVER_FRONT: 3>, desc=u'd', data='B')")
-        else:
-            expected = (
-                "APIC(encoding=<Encoding.LATIN1: 0>, mime='m', "
-                "type=<PictureType.COVER_FRONT: 3>, desc='d', data=b'B')")
+        expected = (
+            "APIC(encoding=<Encoding.LATIN1: 0>, mime='m', "
+            "type=<PictureType.COVER_FRONT: 3>, desc='d', data=b'B')")
 
         self.assertEqual(repr(frame), expected)
         new_frame = APIC()
